	.include "MSP430F44X.h"

LCD_DIV_32		.equ	000h
LCD_DIV_64		.equ	008h
LCD_DIV_128		.equ	010h
LCD_DIV_256		.equ	018h

XCAP18PF		.equ 	030h

RAM_orig  .set		 00200h		 ; Free Memory start address
ROM_orig  .set		 0E000h		 ; ROM start address
USER_END  .set		 0FFFFh		 ; RAM end address
SP_orig   .set		 00280h		 ; stackpointer

;************************************************************************
; Reset : Initialize processor
;************************************************************************

;	.sect "MAIN",ROM_orig
RESET
	mov #SP_orig,SP				   ; initialize stackpointer
	mov #(WDT_HOLD+WDT_WRKEY),&WDTCTL  ; Stop Watchdog Timer
	bis.b #XCAP18PF,&FLL_CTL0       ;set load capacitance for xtal

	bis.b #0C0h,&P5DIR
	bis.b #080h,&P5OUT
	bic.b #080h,&P5OUT
	bis.b #080h,&P5OUT
	bic.b #080h,&P5OUT

	; Setup Basic Timer for LCD operation
;	mov.b #(LCD_DIV_32+024h),&BTCTL
;	mov.b #(LCD_DIV_64+024h),&BTCTL
;	mov.b #(LCD_DIV_128+024h),&BTCTL
;	mov.b #(LCD_DIV_256+024h),&BTCTL

	mov.b #(LCD_DIV_64+024h),&BTCTL

	; Turn on Basic Timer interrupts
	bis.b #BTIE,&IE2

	; Setup port functions
	mov.b #032h,&P1SEL
	mov.b #000h,&P2SEL
	mov.b #000h,&P3SEL
	mov.b #0FCh,&P4SEL
	mov.b #0FFh,&P5SEL

	; Setup LCD
	mov.b #(LCDLASTSEG39|LCDMODE_4MUX|LCDSHOW|LCDMODULEON),&LCDCTL
	; Setup LCD data
	mov.b #00Fh,&LCDMEM1	; S1:S0	
	mov.b #000h,&LCDMEM2	; S3:S2

	mov.b #072h,&LCDMEM3	; S5:S4
	mov.b #033h,&LCDMEM4	; S7:S6
	mov.b #0F7h,&LCDMEM5	; S9:S8
	mov.b #007h,&LCDMEM6	; S11:S10

	mov.b #0E2h,&LCDMEM7	; S13:S12
	mov.b #0C4h,&LCDMEM8	; S15:S14

	mov.b #0F0h,&LCDMEM9	; S17:S16
	mov.b #060h,&LCDMEM10	; S19:S18

	mov.b #0F2h,&LCDMEM11	; S21:S20
	mov.b #004h,&LCDMEM12	; S23:S22

	mov.b #0B2h,&LCDMEM13	; S25:S24
	mov.b #044h,&LCDMEM14	; S27:S26

	mov.b #0E0h,&LCDMEM15	; S29:S28
	mov.b #000h,&LCDMEM16	; S31:S30

	mov.b #032h,&LCDMEM17	; S33:S32
	mov.b #064h,&LCDMEM18	; S35:S34

	mov.b #0F2h,&LCDMEM19	; S37:S36
	mov.b #0F4h,&LCDMEM20	; S39:S38

	; Clear LED
	bis.b #001h,&P1OUT
	; Setup Blinky
	mov.b #073h,&P1DIR

	call #LCD_InitializeAccessories
	call #LCD_SetContrast6
	call #LCD_EnableDigit7

	; Initialize accessory state
	mov #Display_0,R4

	eint

;******************************************************************************
; Mainloop
;******************************************************************************
LoopTop
;	xor.b #001h,&P1OUT    ; Toggle LED
	bic.b #040h,&P1OUT	  ; Clear P1.6

	; Go to sleep
	bis #(CPUOFF+SCG1+SCG0),SR	
	bis.b #040h,&P1OUT	  ; Set P1.6

LoopDemoStuff_Next

	; Demo the symbology
	call R4

	jmp LoopTop

Display_0
	mov #Display_1,R4

	mov.b #02Fh,&LCDMEM1	; S1:S0	
	mov.b #01Fh,&LCDMEM2	; S3:S2

	ret

Display_1
	mov #Display_2,R4
	
	mov.b #02Fh,&LCDMEM1	; S1:S0	
	mov.b #02Dh,&LCDMEM2	; S3:S2
	ret

Display_2
	mov #Display_3,R4

	mov.b #00Fh,&LCDMEM1	; S1:S0	
	mov.b #04Dh,&LCDMEM2	; S3:S2
	ret

Display_3
	mov #Display_4,R4

	mov.b #00Fh,&LCDMEM1	; S1:S0	
	mov.b #08Dh,&LCDMEM2	; S3:S2
	ret

Display_4
	mov #Display_5,R4

	mov.b #02Fh,&LCDMEM1	; S1:S0	
	mov.b #019h,&LCDMEM2	; S3:S2
	ret

Display_5
	mov #Display_6,R4

	mov.b #03Fh,&LCDMEM1	; S1:S0	
	mov.b #029h,&LCDMEM2	; S3:S2
	ret

Display_6
	mov #Display_7,R4

	mov.b #02Fh,&LCDMEM1	; S1:S0	
	mov.b #049h,&LCDMEM2	; S3:S2
	ret

Display_7
	mov #Display_8,R4

	mov.b #03Fh,&LCDMEM1	; S1:S0	
	mov.b #081h,&LCDMEM2	; S3:S2
	ret

Display_8
	mov #Display_9,R4

	mov.b #0BFh,&LCDMEM1	; S1:S0	
	mov.b #011h,&LCDMEM2	; S3:S2
	ret

Display_9
	mov #Display_10,R4

	mov.b #0FFh,&LCDMEM1	; S1:S0	
	mov.b #020h,&LCDMEM2	; S3:S2
	ret

Display_10
	mov #Display_11,R4

	mov.b #0BFh,&LCDMEM1	; S1:S0	
	mov.b #040h,&LCDMEM2	; S3:S2
	ret

Display_11
	mov #Display_0,R4

	mov.b #0FFh,&LCDMEM1	; S1:S0	
	mov.b #08Fh,&LCDMEM2	; S3:S2
	ret

LCD_InitializeAccessories
	; Setup P2.0 to P2.3 and P3.4 to P3.7 for ADJ0..7
	; Setup ADJx for low (enable bit to change contrast)
	bic.b #00Fh,&P2OUT
	bic.b #0F0h,&P3OUT

	call #LCD_SetMaximumContrast

	; Setup P2.7 for AB switch
	bis.b #080h,&P2DIR

	call #LCD_EnableDigit7
	ret

LCD_SetMaximumContrast
LCD_SetContrast8
	; Clear for default
	bic.b #00Fh,&P2DIR
	bic.b #0F0h,&P3DIR
	; Set contrast bit
	bis.b #080h,&P3DIR
	ret

LCD_SetContrast7
	; Clear for default
	bic.b #00Fh,&P2DIR
	bic.b #0F0h,&P3DIR
	; Set contrast bit
	bis.b #040h,&P3DIR
	ret

LCD_SetContrast6
	; Clear for default
	bic.b #00Fh,&P2DIR
	bic.b #0F0h,&P3DIR
	; Set contrast bit
	bis.b #020h,&P3DIR
	ret

LCD_SetContrast5
	; Clear for default
	bic.b #00Fh,&P2DIR
	bic.b #0F0h,&P3DIR
	; Set contrast bit
	bis.b #010h,&P3DIR
	ret

LCD_SetContrast4
	; Clear for default
	bic.b #00Fh,&P2DIR
	bic.b #0F0h,&P3DIR
	; Set contrast bit
	bis.b #008h,&P2DIR
	ret

LCD_SetContrast3
	; Clear for default
	bic.b #00Fh,&P2DIR
	bic.b #0F0h,&P3DIR
	; Set contrast bit
	bis.b #004h,&P2DIR
	ret

LCD_SetContrast2
	; Clear for default
	bic.b #00Fh,&P2DIR
	bic.b #0F0h,&P3DIR
	; Set contrast bit
	bis.b #002h,&P2DIR
	ret

LCD_SetContrast1
	; Clear for default
	bic.b #00Fh,&P2DIR
	bic.b #0F0h,&P3DIR
	; Set contrast bit
	bis.b #001h,&P2DIR
	ret

LCD_SetMinimumContrast
LCD_SetContrast0
	; Setup ADJx for minimum contrast
	bic.b #00Fh,&P2DIR
	bic.b #0F0h,&P3DIR
	ret
	
LCD_EnableProgressBar
	bic.b #080h,&P2OUT
	ret
	
LCD_EnableDigit7
	bis.b #080h,&P2OUT
	ret

Int_BT
	; Wake processor
	bic #(CPUOFF+OSCOFF+SCG1+SCG0),0(SP)
	reti

; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
; Interrupt vectors
; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

	.sect	  "Int_Vect",USER_END-31
	.word	  Int_BT			  ; Basic Timer
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; NMI, Osc. fault
	.word	  RESET				  ; POR, ext. Reset, Watchdog
	.end